@@ -13,6 +13,7 @@ from junky import get_func_params
 from mordl.base_tagger import BaseTagger
 from mordl.defaults import BATCH_SIZE, LOG_FILE, TRAIN_BATCH_SIZE
 from mordl.feat_tagger_model import FeatTaggerModel
+import time
 
 _OP_C_ASIS = 'asis'
 _OP_C_TITLE = 'title'
@@ -374,7 +375,8 @@ class LemmaTagger(BaseTagger):
               rnn_emb_dim=None, cnn_emb_dim=None, cnn_kernels=range(1, 7),
               upos_emb_dim=300, emb_out_dim=512, lstm_hidden_dim=256,
               lstm_layers=3, lstm_do=0, bn1=True, do1=.2, bn2=True, do2=.5,
-              bn3=True, do3=.4, seed=None, log_file=LOG_FILE):
+              bn3=True, do3=.4, seed=None, start_time=None,
+              log_file=LOG_FILE):
         """Creates and trains a LEMMA prediction model.
 
         During training, the best model is saved after each successful epoch.
@@ -494,12 +496,17 @@ class LemmaTagger(BaseTagger):
         **seed** (`int`): init value for the random number generator if you
         need reproducibility.
 
+        **start_time** (`float`): result of `time.time()` to start with. If
+        `None` (default), the arg will be init anew.
+
         **log_file**: a stream for info messages. Default is `sys.stdout`.
 
         The method returns the train statistics.
         """
         assert self._train_corpus, 'ERROR: Train corpus is not loaded yet'
 
+        if not start_time:
+            start_time = time.time()
         args, kwargs = get_func_params(LemmaTagger.train, locals())
 
         self._cdict = CorpusDict(
